==> savane-3.14.tar.gz: savane-3.14/frontend/php/account/impersonate.php <==
<?php
# Become another user for testing his/her problems
# Copyright (C) 1999, 2000 The SourceForge Crew
# Copyright (C) 2000-2006 Mathieu Roy
# Copyright (C) 2014, 2016, 2017 Assaf Gordon
# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
# Copyright (C) 2013, 2014, 2017-2024 Ineiev
#
# This file is part of Savane.
#
# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
# under the terms of the GNU General Public license version 3 or (at your
# option) any later version; further contributions are covered by
# the GNU Affero General Public license version 3 or (at your option)
# any later version.  The license notices for the AGPL and the GPL follow.
#
# Savane is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Savane is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
# Savane is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Savane is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

require_once ('../include/init.php');
if (!user_is_super_user ())
  exit_error (_("You need to be site administrator to use this feature."));

extract (sane_import ('post',
  ['name' => 'user_name', 'internal_uri' => 'uri', true => 'impersonate']
));
form_check ('impersonate');

$new_uid = user_getid ($user_name);
if ($new_uid == 0)
  exit_error (_("This user doesn't exist."));

# Modify session information to become the target user.
extract (sane_import ('cookie', ['hash' => 'session_hash']));
$result = db_execute (
  "UPDATE session SET user_id = ? WHERE session_hash = ?",
  [$new_uid, $session_hash]
);
session_cookie ('session_uid', $new_uid);
session_redirect ($uri);
?>

==> savane-3.15.tar.gz: savane-3.15/frontend/php/account/impersonate.php <==
<?php
# Become another user to test problems.
#
# Copyright (C) 1999, 2000 The SourceForge Crew
# Copyright (C) 2000-2006 Mathieu Roy
# Copyright (C) 2014, 2016, 2017 Assaf Gordon
# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
# Copyright (C) 2013, 2014, 2017-2025 Ineiev
#
# This file is part of Savane.
#
# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
# under the terms of the GNU General Public license version 3 or (at your
# option) any later version; further contributions are covered by
# the GNU Affero General Public license version 3 or (at your option)
# any later version.  The license notices for the AGPL and the GPL follow.
#
# Savane is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Savane is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
# Savane is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Savane is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

require_once ('../include/init.php');
if (!user_is_super_user ())
  exit_error (_("You need to be site administrator to use this feature."));

extract (sane_import ('post',
  ['name' => 'user_name', 'internal_uri' => 'uri', 'true' => 'impersonate']
));
exit_if_missing (['uri', 'user_name', 'impersonate']);
form_check ('impersonate');

$new_uid = user_getid ($user_name);
if ($new_uid == 0)
  exit_user_not_found ($user_name);

# Modify session information to become the target user.
$result = db_execute (
  "UPDATE session SET user_id = ? WHERE session_hash = ?",
  [$new_uid, $G_SESSION['hash_enc']]
);
session_cookie ('session_uid', $new_uid);
session_redirect ($uri);
?>
